#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2016
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    def test_setgetOption(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_setgetOption)

    def run_test_setgetOption(self):
        if sys.platform == 'zos':
            options = {}
        else:
            options = { ibm_db.SQL_ATTR_INFO_PROGRAMNAME : 'TestProgram'}
        conn = ibm_db.connect(config.database, config.user, config.password, options)

        # Get the server type
        serverinfo = ibm_db.server_info( conn )

        if conn:
            if sys.platform != 'zos':
                value=ibm_db.get_option(conn, ibm_db.SQL_ATTR_INFO_PROGRAMNAME, 1)
                print("Connection options:\nSQL_ATTR_INFO_PROGRAMNAME = ", end="")
                print(value)
            else:
                print("Connection options:\n", end="")

            returncode=ibm_db.set_option(conn, {ibm_db.SQL_ATTR_AUTOCOMMIT:0},1)
            value=ibm_db.get_option(conn, ibm_db.SQL_ATTR_AUTOCOMMIT, 1)
            print("SQL_ATTR_AUTOCOMMIT = ", end="")
            print(str(value)+"\n")

            drop = "DROP TABLE TEMP_TEST"
            try:
                result = ibm_db.exec_immediate(conn,drop)
            except:
                pass

            # Create the table temp_test

            create = "CREATE TABLE TEMP_TEST (id INTEGER, name CHAR(16))"
            result = ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO temp_test values (1, 'cat')"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.prepare(conn, "SELECT * FROM temp_test WHERE id > 1" )
            if sys.platform != 'zos':
                returnCode = ibm_db.set_option(stmt, {ibm_db.SQL_ATTR_QUERY_TIMEOUT : 20}, 0)
                value = ibm_db.get_option(stmt, ibm_db.SQL_ATTR_QUERY_TIMEOUT, 0)
                print("Statement options:\nSQL_ATTR_QUERY_TIMEOUT = ", end="")
                print(str(value)+"\n")

            ibm_db.execute(stmt)
            if result:
                ibm_db.free_result(stmt)
            else:
                print(ibm_db.stmt_errormsg())
            ibm_db.rollback(conn)
            ibm_db.close(conn)
        else:
            print ("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Connection options:
#SQL_ATTR_INFO_PROGRAMNAME = TestProgram
#SQL_ATTR_AUTOCOMMIT = 0
#Statement options:
#SQL_ATTR_QUERY_TIMEOUT = 20
#__ZOS_EXPECTED__
#Connection options:
#SQL_ATTR_INFO_PROGRAMNAME = TestProgram
#SQL_ATTR_AUTOCOMMIT = 0
#Statement options:
#SQL_ATTR_QUERY_TIMEOUT = 20
#__SYSTEMI_EXPECTED__
#Connection options:
#SQL_ATTR_INFO_PROGRAMNAME = TestProgram
#SQL_ATTR_AUTOCOMMIT = 0
#Statement options:
#SQL_ATTR_QUERY_TIMEOUT = 20
#__ZOS_ODBC_EXPECTED__
#Connection options:
#SQL_ATTR_AUTOCOMMIT = 0




#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_240_FieldWidthPosName_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_240)

    def run_test_240(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        result = ibm_db.exec_immediate(conn, "select * from sales")
        result2 = ibm_db.exec_immediate(conn, "select * from staff")
        result3 = ibm_db.exec_immediate(conn, "select * from emp_photo")

        for i in range(0, ibm_db.num_fields(result)):
            print(str(i) + ":" + str(ibm_db.field_width(result,i)))

        print("\n-----")

        for i in range(0, ibm_db.num_fields(result2)):
            print(str(i) + ":" + str(ibm_db.field_width(result2,ibm_db.field_name(result2,i))))

        print("\n-----")

        for i in range(0, 3):
            print(str(i) + ":" + str(ibm_db.field_width(result3,i)) + "," + str(ibm_db.field_display_size(result3,i)))

        print("\n-----")
        print("region:%s" % ibm_db.field_type(result,'region'))

        print("5:%s" % ibm_db.field_type(result2,5))

#__END__
#__LUW_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__ZOS_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__SYSTEMI_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#
#-----
#region:False
#5:decimal
#__IDS_EXPECTED__
#0:10
#1:15
#2:15
#3:11
#
#-----
#0:6
#1:9
#2:6
#3:5
#4:6
#5:9
#6:9
#
#-----
#0:6,6
#1:10,10
#2:2147483647,-2
#
#-----
#region:string
#5:decimal
#__ZOS_ODBC_EXPECTED__
#0:10
#1:15
#2:15
#3:10
#-----
#0:5
#1:9
#2:5
#3:5
#4:5
#5:7
#6:7
#-----
#0:6,6
#1:10,10
#2:1048576,2097152
#-----
#region:False
#5:decimal



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_042_FetchTupleMany_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_042)

    def run_test_042(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        #if ({}['EMPNO'] != None):
        #  result = ibm_db.exec_immediate(conn, "select photo_format, picture, length(picture) from emp_photo where photo_format='jpg' and empno='" + {}['EMPNO'] + "'")
        #  row = ibm_db.fetch_array(result)
        #  if row:
        #    # We'll be outputting a
        #    header('Content-type: image/' + row[0])
        #    header('Content-Length: ' + row[2])
        #    print row[1]
        #  else:
        #    print ibm_db.error()
        #  continue
        #else:
        result = ibm_db.exec_immediate(conn, "select EMPNO, PHOTO_FORMAT from emp_photo where photo_format='jpg'")
        row = ibm_db.fetch_tuple(result)
        while ( row ):
            print("<a href='test_042.php?EMPNO=%s' target=_blank>%s (%s)</a><br>" % (row[0], row[0], row[1]))
            row = ibm_db.fetch_tuple(result)

#__END__
#__LUW_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__ZOS_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__SYSTEMI_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>
#__IDS_EXPECTED__
#<a href='test_042.php?EMPNO=000130' target=_blank>000130 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000140' target=_blank>000140 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000150' target=_blank>000150 (jpg)</a><br>
#<a href='test_042.php?EMPNO=000190' target=_blank>000190 (jpg)</a><br>



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_114_NumericTest_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_114)

    def run_test_114(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            drop = "drop table numericliteral"

            try:
                ibm_db.exec_immediate( conn, drop )
            except:
                pass

            create = "create table numericliteral ( id INTEGER, num INTEGER )"
            ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO numericliteral (id, num) values (1,5)"
            ibm_db.exec_immediate(conn, insert)

            insert = "UPDATE numericliteral SET num = '10' WHERE num = '5'"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.prepare(conn, "SELECT * FROM numericliteral")
            ibm_db.execute(stmt)

            result = ibm_db.fetch_row( stmt )
            while ( result ):
                row0 = ibm_db.result(stmt, 0)
                row1 = ibm_db.result(stmt, 1)
                print(row0)
                print(row1)
                result = ibm_db.fetch_row( stmt )
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#1
#10
#__ZOS_EXPECTED__
#1
#10
#__SYSTEMI_EXPECTED__
#1
#10
#__IDS_EXPECTED__
#1
#10



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_03a_ResultNonExistCol(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_03a)

    def run_test_03a(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            stmt = ibm_db.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")

            while ( ibm_db.fetch_row(stmt) ):
                breed = ibm_db.result(stmt, 1)
                print ("string(%d) \"%s\"" % (len(breed), breed))
                if (server.DBMS_NAME[0:3] == 'IDS'):
                    name = ibm_db.result(stmt, "name")
                else:
                    name = ibm_db.result(stmt, "NAME")
                print ("string(%d) \"%s\"" % (len(name), name))

                # following field does not exist in result set
                if (server.DBMS_NAME[0:3] == 'IDS'):
                    name = ibm_db.result(stmt, "passport")
                else:
                    name = ibm_db.result(stmt, "PASSPORT")
                print (name)
            ibm_db.close(conn)

        else:
            print ("Connection failed.")

#__END__
#__LUW_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__ZOS_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__SYSTEMI_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None
#__IDS_EXPECTED__
#string(3) "cat"
#string(16) "Pook            "
#None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_115_NumericTest_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_115)

    def run_test_115(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )
        if (server.DBMS_NAME[0:3] == 'IDS'):
            op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
            ibm_db.set_option(conn, op, 1)

        if conn:
            drop = "drop table numericliteral"
            try:
                ibm_db.exec_immediate( conn, drop )
            except:
                pass

            create = "create table numericliteral ( id INTEGER, data VARCHAR(50) )"
            ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO numericliteral (id, data) values (12, 'NUMERIC LITERAL TEST')"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.prepare(conn, "SELECT data FROM numericliteral")
            ibm_db.execute(stmt)

#      NOTE: This is a workaround
#      function fetch_object() to be implemented...
#      row = ibm_db.fetch_object(stmt, 0)

            class Row:
                pass

            row = Row()
            ibm_db.fetch_row(stmt, 0)
            if (server.DBMS_NAME[0:3] != 'IDS'):
                row.DATA = ibm_db.result(stmt, 'DATA')
            else:
                row.DATA = ibm_db.result(stmt, 'data')
            print(row.DATA)

            insert = "UPDATE numericliteral SET data = '@@@@@@@@@@' WHERE id = '12'"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.prepare(conn, "SELECT data FROM numericliteral")
            ibm_db.execute(stmt)

#      row = ibm_db.fetch_object(stmt, 0)
            ibm_db.fetch_row(stmt, 0)
            if (server.DBMS_NAME[0:3] != 'IDS'):
                row.DATA = ibm_db.result(stmt, 'DATA')
            else:
                row.DATA = ibm_db.result(stmt, 'data')
            print(row.DATA)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__ZOS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__SYSTEMI_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@
#__IDS_EXPECTED__
#NUMERIC LITERAL TEST
#@@@@@@@@@@



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_212_FieldDisplaySize_03(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_212)

    def run_test_212(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        result = ibm_db.exec_immediate(conn, "select * from sales")

        if (server.DBMS_NAME[0:3] == 'IDS'):
            i = "sales_person"
        else:
            i = "SALES_PERSON"

        print("%s size %d" % (i, ibm_db.field_display_size(result,i)))

        i = 2
        print("%d size %d" % (i, ibm_db.field_display_size(result,i)))

#__END__
#__LUW_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__ZOS_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__SYSTEMI_EXPECTED__
#SALES_PERSON size 15
#2 size 15
#__IDS_EXPECTED__
#sales_person size 15
#2 size 15



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_201_MultipleRsltsetsDiffColDefs(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_201)

    def run_test_201(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        serverinfo = ibm_db.server_info( conn )
        server = serverinfo.DBMS_NAME[0:3]
        if (server == 'IDS'):
            procedure = """CREATE FUNCTION multiResults ()
           RETURNING CHAR(16), INT, VARCHAR(32), NUMERIC(7,2);
           
           DEFINE p_name CHAR(16);
           DEFINE p_id INT;
           DEFINE p_breed VARCHAR(32);
           DEFINE p_weight NUMERIC(7,2);
           
           FOREACH c1 FOR
              SELECT name, id, breed, weight
              INTO p_name, p_id, p_breed, p_weight
              FROM animals
              ORDER BY name DESC
              RETURN p_name, p_id, p_breed, p_weight WITH RESUME;
           END FOREACH;
    
       END FUNCTION;"""
        else:
            procedure = """CREATE PROCEDURE multiResults ()
        RESULT SETS 3
        LANGUAGE SQL
        BEGIN
         DECLARE c1 CURSOR WITH RETURN FOR
          SELECT name, id
          FROM animals
          ORDER BY name;
    
         DECLARE c2 CURSOR WITH RETURN FOR
          SELECT name, id, breed, weight
          FROM animals
          ORDER BY name DESC;
    
         DECLARE c3 CURSOR WITH RETURN FOR
          SELECT name
          FROM animals
          ORDER BY name;
    
         OPEN c1;
         OPEN c2;
         OPEN c3;
        END"""

        if conn:
            try:
                ibm_db.exec_immediate(conn, 'DROP PROCEDURE multiResults')
            except:
                pass
            ibm_db.exec_immediate(conn, procedure)
            if sys.platform == 'zos':
                stmt = ibm_db.exec_immediate(conn, 'CALL MULTIRESULTS()')
            else:
                stmt = ibm_db.exec_immediate(conn, 'CALL multiresults()')

            print("Fetching first result set")
            row = ibm_db.fetch_tuple(stmt)
            while ( row ):
                for i in row:
                    print(str(i).strip())
                row = ibm_db.fetch_tuple(stmt)

            if (server == 'IDS') :
                print("Fetching second result set (should fail -- IDS does not support multiple result sets)")
            else:
                print("Fetching second result set")
            res = ibm_db.next_result(stmt)

            if res:
                row = ibm_db.fetch_tuple(res)
                while ( row ):
                    for i in row:
                        print(str(i).strip())
                    row = ibm_db.fetch_tuple(res)

            if (server == 'IDS'):
                print("Fetching third result set (should fail -- IDS does not support multiple result sets)")
            else:
                print("Fetching third result set")
            res2 = ibm_db.next_result(stmt)
            if res2:
                row = ibm_db.fetch_tuple(res2)
                while ( row ):
                    for i in row:
                        print(str(i).strip())
                    row = ibm_db.fetch_tuple(res2)

            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__ZOS_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__SYSTEMI_EXPECTED__
#Fetching first result set
#Bubbles
#3
#Gizmo
#4
#Peaches
#1
#Pook
#0
#Rickety Ride
#5
#Smarty
#2
#Sweater
#6
#Fetching second result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching third result set
#Bubbles
#Gizmo
#Peaches
#Pook
#Rickety Ride
#Smarty
#Sweater
#__IDS_EXPECTED__
#Fetching first result set
#Sweater
#6
#llama
#150.00
#Smarty
#2
#horse
#350.00
#Rickety Ride
#5
#goat
#9.70
#Pook
#0
#cat
#3.20
#Peaches
#1
#dog
#12.30
#Gizmo
#4
#budgerigar
#0.20
#Bubbles
#3
#gold fish
#0.10
#Fetching second result set (should fail -- IDS does not support multiple result sets)
#Fetching third result set (should fail -- IDS does not support multiple result sets)



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_070_Close(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_070)

    def run_test_070(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            if (type(conn) == ibm_db.IBM_DBConnection):
                print("Resource is a DB2 Connection")

            rc = ibm_db.close(conn)

            print(rc)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Resource is a DB2 Connection
#True
#__ZOS_EXPECTED__
#Resource is a DB2 Connection
#True
#__SYSTEMI_EXPECTED__
#Resource is a DB2 Connection
#True
#__IDS_EXPECTED__
#Resource is a DB2 Connection
#True



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
import platform
import ibm_db_ctx

from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    @unittest.skipIf(platform.system() == 'z/OS',"Test fails with z/OS ODBC driver")
    def test_context_ConnActive(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_context_ConnActive)

    def run_test_context_ConnActive(self):
        conn = None
        is_alive = ibm_db.active(conn)
        if is_alive:
            print("Is active")
        else:
            print("Is not active")

        with ibm_db_ctx.Db2connect(config.database, config.user, config.password) as conn:
            is_alive = ibm_db.active(conn)
            if is_alive:
                print("Is active")
            else:
                print("Is not active")

        is_alive = ibm_db.active(conn)
        if is_alive:
            print("Is active")
        else:
            print("Is not active")


#__END__
#__LUW_EXPECTED__
#Is not active
#Is active
#Is not active
#__ZOS_EXPECTED__
#Is not active
#Is active
#Is not active
#__SYSTEMI_EXPECTED__
#Is not active
#Is active
#Is not active
#__IDS_EXPECTED__
#Is not active
#Is active
#Is not active


#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_071_CloseSuccess(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_071)

    def run_test_071(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            rc = ibm_db.close(conn)
            if (rc == True):
                print("ibm_db.close succeeded")
            else:
                print("ibm_db.close FAILED\n")
        else:
            print("%s" % ibm_db.conn_errormsg())
            print(",sqlstate=%s" % ibm_db.conn_error())
            print("%s" % ibm_db.conn_errormsg())
            print("%s" % ibm_db.conn_errormsg())
            print("%s" % ibm_db.conn_errormsg())
            print("%s" % ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#ibm_db.close succeeded
#__ZOS_EXPECTED__
#ibm_db.close succeeded
#__SYSTEMI_EXPECTED__
#ibm_db.close succeeded
#__IDS_EXPECTED__
#ibm_db.close succeeded



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_031_ResultIndexPosition(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_031)

    def run_test_031(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            stmt = ibm_db.exec_immediate(conn, "SELECT id, breed, name, weight FROM animals WHERE id = 0")

            while (ibm_db.fetch_row(stmt)):
                id = ibm_db.result(stmt, 0)
                print("int(%d)" % id)
                breed = ibm_db.result(stmt, 1)
                print("string(%d) \"%s\"" % (len(breed), breed))
                name = ibm_db.result(stmt, 2)
                print("string(%d) \"%s\"" % (len(name), name))
                weight = ibm_db.result(stmt, 3)
                print("string(%d) \"%s\"" % (len(str(weight)), weight))
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__ZOS_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__SYSTEMI_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"
#__IDS_EXPECTED__
#int(0)
#string(3) "cat"
#string(16) "Pook            "
#string(4) "3.20"



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_220_PersistentConn(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_220)

    def run_test_220(self):
        if sys.platform == 'zos':
            conn = ibm_db.pconnect(config.database,'','')
        else:
            conn = ibm_db.pconnect(config.database, config.user, config.password)

        if conn:
            ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)
            stmt = ibm_db.exec_immediate(conn, "UPDATE animals SET name = 'flyweight' WHERE weight < 10.0")
            print("Number of affected rows:", ibm_db.num_rows( stmt ))
            ibm_db.rollback(conn)
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Number of affected rows: 4
#__ZOS_EXPECTED__
#Number of affected rows: 4
#__SYSTEMI_EXPECTED__
#Number of affected rows: 4
#__IDS_EXPECTED__
#Number of affected rows: 4



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_047_FetchTupleMany_06(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_047)

    def run_test_047(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )
        if (server.DBMS_NAME[0:3] == 'IDS'):
            result = ibm_db.exec_immediate(conn, "SELECT empno, photo_format, photo_format from emp_photo")
        else:
            result = ibm_db.exec_immediate(conn, "SELECT empno, photo_format, length(PICTURE) from emp_photo")
        row = ibm_db.fetch_tuple(result)
        while ( row ):
            if (row[1] == 'gif'):
                print("<img src='test_047.php?EMPNO=%s&FORMAT=%s'><br>\n" % (row[0], row[1]))
            if (row[1] != 'xwd'):
                print("<a href='test_047.php?EMPNO=%s&FORMAT=%s' target=_blank>%s - %s - %s bytes</a>\n<br>" % (row[0], row[1], row[0], row[1], row[2]))
            row = ibm_db.fetch_tuple(result)
#__END__
#__LUW_EXPECTED__
#<a href='test_047.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a>
#<br>
#__ZOS_EXPECTED__
#<a href='test_047.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a>
#<br>
#__SYSTEMI_EXPECTED__
#<a href='test_047.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - 10291 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - 15398 bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - 10291 bytes</a>
#<br>
#__IDS_EXPECTED__
#<a href='test_047.php?EMPNO=000130&FORMAT=jpg' target=_blank>000130 - jpg - jpg bytes</a>
#<br><a href='test_047.php?EMPNO=000130&FORMAT=png' target=_blank>000130 - png - png bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=jpg' target=_blank>000140 - jpg - jpg bytes</a>
#<br><a href='test_047.php?EMPNO=000140&FORMAT=png' target=_blank>000140 - png - png bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=jpg' target=_blank>000150 - jpg - jpg bytes</a>
#<br><a href='test_047.php?EMPNO=000150&FORMAT=png' target=_blank>000150 - png - png bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=jpg' target=_blank>000190 - jpg - jpg bytes</a>
#<br><a href='test_047.php?EMPNO=000190&FORMAT=png' target=_blank>000190 - png - png bytes</a>
#<br>



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_122_FieldNameDiffCaseColNames(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_122)

    def run_test_122(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            drop = "drop table ftest"
            try:
                ibm_db.exec_immediate( conn, drop )
            except:
                pass

            create = "create table ftest ( \"TEST\" integer, \"test\" integer, \"Test\" integer  )"
            ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO ftest values (1,2,3)"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.exec_immediate(conn, "SELECT * FROM ftest")

            num1 = ibm_db.field_name(stmt, 0)
            num2 = ibm_db.field_name(stmt, 1)
            num3 = ibm_db.field_name(stmt, 2)

            num4 = ibm_db.field_name(stmt, "TEST")
            num5 = ibm_db.field_name(stmt, 'test')
            num6 = ibm_db.field_name(stmt, 'Test')

            print("string(%d) \"%s\"" % (len(num1), num1))
            print("string(%d) \"%s\"" % (len(num2), num2))
            print("string(%d) \"%s\"" % (len(num3), num3))

            print("string(%d) \"%s\"" % (len(num4), num4))
            print("string(%d) \"%s\"" % (len(num5), num5))
            print("string(%d) \"%s\"" % (len(num6), num6))

        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__ZOS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__SYSTEMI_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#__IDS_EXPECTED__
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"
#string(4) "TEST"
#string(4) "test"
#string(4) "Test"



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2024
#

from __future__ import print_function
import sys
import unittest
import os
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_sp_return(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_sp_return)

    def run_test_sp_return(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        serverinfo = ibm_db.server_info( conn )
        server = serverinfo.DBMS_NAME[0:3]

        if (server == 'IDS'):
            procedure = """CREATE PROCEDURE TEST_SP_RETURN( ); declare retval integer;set retval = 100;return retval;END PROCEDURE;"""
        else:
            procedure = """CREATE PROCEDURE TEST_SP_RETURN( )
                           LANGUAGE SQL
                           BEGIN
                           declare retval integer;
                           set retval = 100;
                           return retval;
                           End
                        """

        if conn:
            try:
                ibm_db.exec_immediate(conn, 'DROP PROCEDURE TEST_SP_RETURN')
            except:
                pass
            ibm_db.exec_immediate(conn, procedure)

            stmt = ibm_db.callproc(conn, "TEST_SP_RETURN",( ))
            value =ibm_db.get_option(stmt, ibm_db.SQL_ATTR_CALL_RETURN,0)
            print(value)

            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#100
#__ZOS_EXPECTED__
#100
#__SYSTEMI_EXPECTED__
#100
#__IDS_EXPECTED__
#100


#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions
import ibm_db_ctx

class IbmDbTestCase(unittest.TestCase):

    def test_context_ConnDb(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_context_ConnDb)

    def run_test_context_ConnDb(self):
        with ibm_db_ctx.Db2connect(config.database, config.user, config.password) as conn:
            print("Connection succeeded.")
		   

#__END__
#__LUW_EXPECTED__
#Connection succeeded.
#__ZOS_EXPECTED__
#Connection succeeded.
#__SYSTEMI_EXPECTED__
#Connection succeeded.
#__IDS_EXPECTED__
#Connection succeeded.


#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#
# NOTE: IDS requires that you pass the schema name (cannot pass None)

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_190_ColumnsTable_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_190)

    def run_test_190(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.columns(conn,None,config.user,"employee")
            else:
                result = ibm_db.columns(conn,None,(config.user).upper(),"EMPLOYEE")

            row = ibm_db.fetch_tuple(result)
            while ( row ):
                str = row[1] + "/" + row[3]
                print(str)
                row = ibm_db.fetch_tuple(result)
            print("done!")
        else:
            print("no connection:", ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__ZOS_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__SYSTEMI_EXPECTED__
#%s/EMPNO
#%s/FIRSTNME
#%s/MIDINIT
#%s/LASTNAME
#%s/WORKDEPT
#%s/PHONENO
#%s/HIREDATE
#%s/JOB
#%s/EDLEVEL
#%s/SEX
#%s/BIRTHDATE
#%s/SALARY
#%s/BONUS
#%s/COMM
#done!
#__IDS_EXPECTED__
#%s/empno
#%s/firstnme
#%s/midinit
#%s/lastname
#%s/workdept
#%s/phoneno
#%s/hiredate
#%s/job
#%s/edlevel
#%s/sex
#%s/birthdate
#%s/salary
#%s/bonus
#%s/comm
#done!



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_6528_ScopingProblemBindParam(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_6528)

    def checked_db2_execute(self, stmt):
        ibm_db.execute(stmt)
        row = ibm_db.fetch_tuple(stmt)
        for i in row:
            print(i)

    def run_test_6528(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        if conn:
            if (server.DBMS_NAME[0:3] == 'IDS'):
                sql = "SELECT TRIM(TRAILING FROM name) FROM animals WHERE breed = ?"
            else:
                sql = "SELECT RTRIM(name) FROM animals WHERE breed = ?"
            stmt = ibm_db.prepare(conn, sql)
            var = "cat"
            ibm_db.bind_param(stmt, 1, var, ibm_db.SQL_PARAM_INPUT)
            self.checked_db2_execute(stmt)
            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#Pook
#__ZOS_EXPECTED__
#Pook
#__SYSTEMI_EXPECTED__
#Pook
#__IDS_EXPECTED__
#Pook



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_092_ConnmsgWrongPwd(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_092)

    def run_test_092(self):
        try:
            conn = ibm_db.connect(config.database, config.user, "z")
            print("??? No way.")
        except:
            err = ibm_db.conn_errormsg()
            print(err)

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__ZOS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__IDS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001 SQLCODE=-30082
#__ZOS_ODBC_EXPECTED__
#??? No way.



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2025
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_316_stmtErrormsg_stmtError_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_316)

    def run_test_316(self):
        conn = ibm_db_dbi.connect(config.database, config.user, config.password)
        cursor = conn.cursor()

        try:
            cursor.execute("INVALID SQL")
        except Exception:
            print(cursor.stmt_errormsg())
            print(cursor.stmt_error())

        cursor.close()
        conn.close()

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver][DB2/LINUXX8664] SQL0104N  An unexpected token "END-OF-STATEMENT" was found following "INVALID SQL".  Expected tokens may include:  "JOIN <joined_table>".  SQLSTATE=42601  SQLCODE=-104
#42601
#__ZOS_EXPECTED__
#[IBM][CLI Driver][DB2/LINUXX8664] SQL0104N  An unexpected token "END-OF-STATEMENT" was found following "INVALID SQL".  Expected tokens may include:  "JOIN <joined_table>".  SQLSTATE=42601  SQLCODE=-104
#42601
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver][AS] SQL0104N  An unexpected token "END-OF-STATEMENT" was found following "INVALID SQL".  Expected tokens may include:  "JOIN <joined_table>".  SQLSTATE=42601  SQLCODE=-104
#42601
#__IDS_EXPECTED__
#[IBM][CLI Driver][IDS/LINUXX8664] SQL0104N  An unexpected token "END-OF-STATEMENT" was found following "INVALID SQL".  Expected tokens may include:  "JOIN <joined_table>".  SQLSTATE=42601  SQLCODE=-104
#42601



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_113_DateTest(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_113)

    def run_test_113(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            drop = "DROP TABLE datetest"
            try:
                ibm_db.exec_immediate( conn, drop )
            except:
                pass

            create = "CREATE TABLE datetest ( id INTEGER, mydate DATE )"
            ibm_db.exec_immediate(conn, create)

            server = ibm_db.server_info( conn )
            if (server.DBMS_NAME[0:3] == 'IDS'):
                insert = "INSERT INTO datetest (id, mydate) VALUES (1,'1982-03-27')"
                ibm_db.exec_immediate(conn, insert)
                insert = "INSERT INTO datetest (id, mydate) VALUES (2,'1981-07-08')"
                ibm_db.exec_immediate(conn, insert)
            else:
                insert = "INSERT INTO datetest (id, mydate) VALUES (1,'1982-03-27')"
                ibm_db.exec_immediate(conn, insert)
                insert = "INSERT INTO datetest (id, mydate) VALUES (2,'1981-07-08')"
                ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.prepare(conn, "SELECT * FROM datetest")
            ibm_db.execute(stmt)

            result = ibm_db.fetch_row( stmt )
            while ( result ):
                row0 = ibm_db.result(stmt, 0)
                row1 = ibm_db.result(stmt, 1)
                print(row0)
                print(row1)
                result = ibm_db.fetch_row( stmt )
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__ZOS_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__SYSTEMI_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08
#__IDS_EXPECTED__
#1
#1982-03-27
#2
#1981-07-08



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_112_FieldNumDiffCaseColNames(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_112)

    def run_test_112(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            drop = "DROP TABLE ftest"
            try:
                ibm_db.exec_immediate( conn, drop )
            except:
                pass

            create = "CREATE TABLE ftest ( \"TEST\" INTEGER, \"test\" INTEGER, \"Test\" INTEGER  )"
            ibm_db.exec_immediate(conn, create)

            insert = "INSERT INTO ftest VALUES (1,2,3)"
            ibm_db.exec_immediate(conn, insert)

            stmt = ibm_db.exec_immediate(conn, "SELECT * FROM ftest")

            num1 = ibm_db.field_num(stmt, "TEST")
            num2 = ibm_db.field_num(stmt, 'test')
            num3 = ibm_db.field_num(stmt, 'Test')

            print("int(%d)" % num1)
            print("int(%d)" % num2)
            print("int(%d)" % num3)

        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#int(0)
#int(1)
#int(2)
#__ZOS_EXPECTED__
#int(0)
#int(1)
#int(2)
#__SYSTEMI_EXPECTED__
#int(0)
#int(1)
#int(2)
#__IDS_EXPECTED__
#int(0)
#int(1)
#int(2)



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_300_ServerInfo(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_300)

    def run_test_300(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info(conn)

        if server:
            print("DBMS_NAME: string(%d) \"%s\"" % (len(server.DBMS_NAME), server.DBMS_NAME))
            print("DBMS_VER: string(%d) \"%s\"" % (len(server.DBMS_VER), server.DBMS_VER))
            print("DB_CODEPAGE: int(%d)" % server.DB_CODEPAGE)
            print("DB_NAME: string(%d) \"%s\"" % (len(server.DB_NAME), server.DB_NAME))
            print("INST_NAME: string(%d) \"%s\"" % (len(server.INST_NAME), server.INST_NAME))
            print("SPECIAL_CHARS: string(%d) \"%s\"" % (len(server.SPECIAL_CHARS), server.SPECIAL_CHARS))
            print("KEYWORDS: int(%d)" % len(server.KEYWORDS))
            print("DFT_ISOLATION: string(%d) \"%s\"" % (len(server.DFT_ISOLATION), server.DFT_ISOLATION))
            il = ''
            for opt in server.ISOLATION_OPTION:
                il += opt + " "
            print("ISOLATION_OPTION: string(%d) \"%s\"" % (len(il), il))
            print("SQL_CONFORMANCE: string(%d) \"%s\"" % (len(server.SQL_CONFORMANCE), server.SQL_CONFORMANCE))
            print("PROCEDURES:", server.PROCEDURES)
            print("IDENTIFIER_QUOTE_CHAR: string(%d) \"%s\"" % (len(server.IDENTIFIER_QUOTE_CHAR), server.IDENTIFIER_QUOTE_CHAR))
            print("LIKE_ESCAPE_CLAUSE:", server.LIKE_ESCAPE_CLAUSE)
            print("MAX_COL_NAME_LEN: int(%d)" % server.MAX_COL_NAME_LEN)
            print("MAX_ROW_SIZE: int(%d)" % server.MAX_ROW_SIZE)
            print("MAX_IDENTIFIER_LEN: int(%d)" % server.MAX_IDENTIFIER_LEN)
            print("MAX_INDEX_SIZE: int(%d)" % server.MAX_INDEX_SIZE)
            print("MAX_PROC_NAME_LEN: int(%d)" % server.MAX_PROC_NAME_LEN)
            print("MAX_SCHEMA_NAME_LEN: int(%d)" % server.MAX_SCHEMA_NAME_LEN)
            print("MAX_STATEMENT_LEN: int(%d)" % server.MAX_STATEMENT_LEN)
            print("MAX_TABLE_NAME_LEN: int(%d)" % server.MAX_TABLE_NAME_LEN)
            print("NON_NULLABLE_COLUMNS:", server.NON_NULLABLE_COLUMNS)

            ibm_db.close(conn)
        else:
            print("Error.")

#__END__
#__LUW_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__ZOS_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__SYSTEMI_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s
#__IDS_EXPECTED__
#DBMS_NAME: string(%d) %s
#DBMS_VER: string(%d) %s
#DB_CODEPAGE: int(%d)
#DB_NAME: string(%d) %s
#INST_NAME: string(%d) %s
#SPECIAL_CHARS: string(%d) %s
#KEYWORDS: int(%d)
#DFT_ISOLATION: string(%d) %s
#ISOLATION_OPTION: string(%d) %s
#SQL_CONFORMANCE: string(%d) %s
#PROCEDURES: %s
#IDENTIFIER_QUOTE_CHAR: string(%d) %s
#LIKE_ESCAPE_CLAUSE: %s
#MAX_COL_NAME_LEN: int(%d)
#MAX_ROW_SIZE: int(%d)
#MAX_IDENTIFIER_LEN: int(%d)
#MAX_INDEX_SIZE: int(%d)
#MAX_PROC_NAME_LEN: int(%d)
#MAX_SCHEMA_NAME_LEN: int(%d)
#MAX_STATEMENT_LEN: int(%d)
#MAX_TABLE_NAME_LEN: int(%d)
#NON_NULLABLE_COLUMNS: %s



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2025
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_320_EmptyFetchMethods_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_320)

    def run_test_320(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

        dbi_conn = ibm_db_dbi.Connection(conn)

        # Drop the test table, if exists
        drop = 'DROP TABLE dbiEmployeesEmpty'
        try:
            cur = dbi_conn.cursor()
            cur.execute(drop)
        except:
            pass

        # Create the test table (empty)
        create = 'CREATE TABLE dbiEmployeesEmpty (id INT PRIMARY KEY NOT NULL, name VARCHAR(255), age INT)'
        cur = dbi_conn.cursor()
        cur.execute(create)

        dbi_conn.commit()

        # 1) fetchone example on empty table
        cur1 = dbi_conn.cursor()
        cur1.execute('SELECT * FROM dbiEmployeesEmpty ORDER BY id')
        row = cur1.fetchone()
        print("fetchone():", row)

        # 2) fetchmany example on empty table
        cur2 = dbi_conn.cursor()
        cur2.execute('SELECT * FROM dbiEmployeesEmpty ORDER BY id')
        rows = cur2.fetchmany(2)
        print("fetchmany(2):", rows)

        # 3) fetchall example on empty table
        cur3 = dbi_conn.cursor()
        cur3.execute('SELECT * FROM dbiEmployeesEmpty ORDER BY id')
        all_rows = cur3.fetchall()
        print("fetchall():", all_rows)

#__END__
#__LUW_EXPECTED__
#fetchone(): None
#fetchmany(2): []
#fetchall(): []
#__ZOS_EXPECTED__
#fetchone(): None
#fetchmany(2): []
#fetchall(): []
#__SYSTEMI_EXPECTED__
#fetchone(): None
#fetchmany(2): []
#fetchall(): []
#__IDS_EXPECTED__
#fetchone(): None
#fetchmany(2): []
#fetchall(): []



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_251_FreeResult_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_251)

    def run_test_251(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        result = ibm_db.exec_immediate(conn, "select * from sales")

        r1 = ibm_db.free_result(result)
        r2 = ibm_db.free_result(result)
        r3 = ''
        try:
            r3 = ibm_db.free_result(result99)  # noqa: F821
        except:
            r3 = None

        print(r1)
        print(r2)
        print(r3)

#__END__
#__LUW_EXPECTED__
#True
#True
#None
#__ZOS_EXPECTED__
#True
#True
#None
#__SYSTEMI_EXPECTED__
#True
#True
#None
#__IDS_EXPECTED__
#True
#True
#None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_050_AutocommitStatus(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_050)

    def run_test_050(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        ac = ibm_db.autocommit(conn)

        print(ac)

#__END__
#__LUW_EXPECTED__
#1
#__ZOS_EXPECTED__
#1
#__SYSTEMI_EXPECTED__
#1
#__IDS_EXPECTED__
#1



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2025
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
import decimal
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_321_FetchWithDatatypesMethods_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_321)

    def _format_blob_rows(self, rows):
        """Convert memoryview BLOBs to strings for consistent output."""
        formatted = []
        for row in rows:
            id_, dec_val, blob_mv = row
            blob_bytes = bytes(blob_mv)
            blob_str = blob_bytes.decode('utf-8')
            formatted.append((id_, dec_val, blob_str))
        return formatted

    def run_test_321(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)
        dbi_conn = ibm_db_dbi.Connection(conn)

        cur = dbi_conn.cursor()

        try:
            cur.execute("DROP TABLE dbiEmployeesDatatypes")
        except:
            pass

        create_sql = '''
            CREATE TABLE dbiEmployeesDatatypes (
                id INT PRIMARY KEY NOT NULL,
                SMTH DECIMAL(10,2),
                BDATA BLOB
            )
        '''
        cur.execute(create_sql)
        dbi_conn.commit()

        insert_sql = 'INSERT INTO dbiEmployeesDatatypes (id, SMTH, BDATA) VALUES (?, ?, ?)'
        for i in range(1, 6):
            dec_val = decimal.Decimal(f"{1000 + i * 0.5:.2f}")
            blob_val = f"Blob data {i}".encode("utf-8")
            cur.execute(insert_sql, (i, dec_val, blob_val))

        dbi_conn.commit()

        select_sql = "SELECT * FROM dbiEmployeesDatatypes ORDER BY id"

        # fetchall
        cur.execute(select_sql)
        all_rows = cur.fetchall()
        print(self._format_blob_rows(all_rows))

        # fetchmany(2)
        cur2 = dbi_conn.cursor()
        cur2.execute(select_sql)
        many_rows = cur2.fetchmany(2)
        print(self._format_blob_rows(many_rows))

        # fetchone
        cur3 = dbi_conn.cursor()
        cur3.execute(select_sql)
        one_row = cur3.fetchone()
        # format fetchone single row as tuple (id, decimal, string)
        id_, dec_val, blob_mv = one_row
        blob_str = bytes(blob_mv).decode('utf-8')
        print((id_, dec_val, blob_str))


#__END__
#__LUW_EXPECTED__
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2'), (3, Decimal('1001.50'), 'Blob data 3'), (4, Decimal('1002.00'), 'Blob data 4'), (5, Decimal('1002.50'), 'Blob data 5')]
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2')]
#(1, Decimal('1000.50'), 'Blob data 1')
#__ZOS_EXPECTED__
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2'), (3, Decimal('1001.50'), 'Blob data 3'), (4, Decimal('1002.00'), 'Blob data 4'), (5, Decimal('1002.50'), 'Blob data 5')]
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2')]
#(1, Decimal('1000.50'), 'Blob data 1')
#__SYSTEMI_EXPECTED__
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2'), (3, Decimal('1001.50'), 'Blob data 3'), (4, Decimal('1002.00'), 'Blob data 4'), (5, Decimal('1002.50'), 'Blob data 5')]
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2')]
#(1, Decimal('1000.50'), 'Blob data 1')
#__IDS_EXPECTED__
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2'), (3, Decimal('1001.50'), 'Blob data 3'), (4, Decimal('1002.00'), 'Blob data 4'), (5, Decimal('1002.50'), 'Blob data 5')]
#[(1, Decimal('1000.50'), 'Blob data 1'), (2, Decimal('1001.00'), 'Blob data 2')]
#(1, Decimal('1000.50'), 'Blob data 1')


#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_bool_callproc(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_bool_callproc)

    def run_test_bool_callproc(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        if (not conn):
            print("Could not make a connection.")
            return 0
        server = ibm_db.server_info( conn )

        if( not server.DBMS_NAME.startswith('DB2/')):
            print("Boolean is not supported")
            return 0

        try:
            ibm_db.exec_immediate(conn,"DROP PROCEDURE bool_procparams")
            ibm_db.exec_immediate(conn,"DROP TABLE bool_test")
        except:
            pass

        try:
            ibm_db.exec_immediate(conn, "CREATE TABLE bool_test(col1 BOOLEAN, description varchar(50))")
        except:
            pass

        try:
            procedure = """create procedure bool_procparams(in parm1 boolean, out param2 boolean)
                           RESULT SETS  1
                           LANGUAGE SQL
                           BEGIN
                             DECLARE c1 CURSOR WITH RETURN FOR SELECT * from bool_test;
                             OPEN c1;
                             set param2 = parm1;
                           END"""

            ibm_db.exec_immediate(conn,procedure )
        except Exception as e:
            print(str(e))
            exit(-1)

        try:
            insert_sql = "INSERT INTO bool_test values(?, ?)"
            stmt = ibm_db.prepare(conn, insert_sql)

            rows = (
                (True, 'bindparam true'),
                (False, 'bindparam false'),
                (None, 'bindparam None')
            )

            for row in rows:
                ibm_db.bind_param(stmt, 1, row[0])
                ibm_db.bind_param(stmt, 2, row[1])
                ibm_db.execute(stmt)
            stmt = None

            inparam = 11
            outparam = -1
            stmt, inparam, outparam = ibm_db.callproc(conn, 'bool_procparams',(inparam,outparam))
            print("Fetching first result set")
            row = ibm_db.fetch_row(stmt)
            while row:
                row0 = ibm_db.result(stmt, 0)
                row1 = ibm_db.result(stmt, 1)
                print(row0)
                print(row1)
                row = ibm_db.fetch_row( stmt )

            ibm_db.close(conn)
        except Exception as e:
            print("Error:{}".format(str(e)))


#__END__
#__LUW_EXPECTED__
#Fetching first result set
#True
#bindparam true
#False
#bindparam false
#None
#bindparam None
#__ZOS_EXPECTED__
#Boolean is not supported
#__SYSTEMI_EXPECTED__
#Boolean is not supported
#__IDS_EXPECTED__
#Boolean is not supported



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):
    
    def test_314_FetchAll(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_314)

    def run_test_314(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        ibm_db.autocommit(conn, ibm_db.SQL_AUTOCOMMIT_OFF)

        # Drop the test table, in case it exists
        drop = 'DROP TABLE animals'
        try:
            result = ibm_db.exec_immediate(conn, drop)
        except:
            pass

        # Create the test table
        create = 'CREATE TABLE animals (id INTEGER, breed VARCHAR(32), name VARCHAR(16), weight DECIMAL(7,2))'
        result = ibm_db.exec_immediate(conn, create)
        
        insert = "INSERT INTO animals values (0, 'cat', 'Pook', 3.2)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (1, 'dog', 'Max', 12.5)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (2, 'parrot', 'Polly', 0.8)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (3, 'rabbit', 'Bunny', 2.3)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (4, 'hamster', 'Nibbles', 0.5)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (5, 'fish', 'Bubbles', 0.2)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (6, 'snake', 'Slither', 1.1)"
        ibm_db.exec_immediate(conn, insert)
        
        insert = "INSERT INTO animals values (7, 'horse', 'Thunder', 450.7)"
        ibm_db.exec_immediate(conn, insert)

        stmt = ibm_db.exec_immediate(conn, "select * from animals")

        allRows = ibm_db.fetchall(stmt)

        print(allRows)

        ibm_db.rollback(conn)

#__END__
#__LUW_EXPECTED__
#[(0, 'cat', 'Pook', '3.20'), (1, 'dog', 'Max', '12.50'), (2, 'parrot', 'Polly', '0.80'), (3, 'rabbit', 'Bunny', '2.30'), (4, 'hamster', 'Nibbles', '0.50'), (5, 'fish', 'Bubbles', '0.20'), (6, 'snake', 'Slither', '1.10'), (7, 'horse', 'Thunder', '450.70')]
#__ZOS_EXPECTED__
#[(0, 'cat', 'Pook', '3.20'), (1, 'dog', 'Max', '12.50'), (2, 'parrot', 'Polly', '0.80'), (3, 'rabbit', 'Bunny', '2.30'), (4, 'hamster', 'Nibbles', '0.50'), (5, 'fish', 'Bubbles', '0.20'), (6, 'snake', 'Slither', '1.10'), (7, 'horse', 'Thunder', '450.70')]
#__SYSTEMI_EXPECTED__
#[(0, 'cat', 'Pook', '3.20'), (1, 'dog', 'Max', '12.50'), (2, 'parrot', 'Polly', '0.80'), (3, 'rabbit', 'Bunny', '2.30'), (4, 'hamster', 'Nibbles', '0.50'), (5, 'fish', 'Bubbles', '0.20'), (6, 'snake', 'Slither', '1.10'), (7, 'horse', 'Thunder', '450.70')]
#__IDS_EXPECTED__
#[(0, 'cat', 'Pook', '3.20'), (1, 'dog', 'Max', '12.50'), (2, 'parrot', 'Polly', '0.80'), (3, 'rabbit', 'Bunny', '2.30'), (4, 'hamster', 'Nibbles', '0.50'), (5, 'fish', 'Bubbles', '0.20'), (6, 'snake', 'Slither', '1.10'), (7, 'horse', 'Thunder', '450.70')]



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

# This test will use a lot of the heap size allocated
# for DB2.  If is is failing on your system, please
# increase the application heap size.

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_156_FetchAssocNestedSelects_01(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_156)

    def run_test_156(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )
        if (server.DBMS_NAME[0:3] == 'IDS'):
            op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
            ibm_db.set_option(conn, op, 1)

        result = ibm_db.exec_immediate(conn, "select * from staff")

        row = ibm_db.fetch_assoc(result)
        count = 1
        while ( row ):
            if (row['YEARS'] == None):
                row['YEARS'] = ''
            if (row['COMM'] == None):
                row['COMM'] = ''
            print(row['ID'],row['NAME'],row['JOB'],row['YEARS'], row['SALARY'], row['COMM'])
            row = ibm_db.fetch_assoc(result)

        result2 = ibm_db.exec_immediate(conn,"select * from department where substr(deptno,1,1) in ('A','B','C','D','E')")
        row2 = ibm_db.fetch_assoc(result2)
        while ( row2 ):
            if (row2['MGRNO'] == None):
                row2['MGRNO'] = ''
            print(row2['DEPTNO'], row2['DEPTNAME'], row2['MGRNO'], row2['ADMRDEPT'], row2['LOCATION'])
            row2 = ibm_db.fetch_assoc(result2)

#__END__
#__LUW_EXPECTED__
#10 Sanders Mgr   7 18357.50 
#20 Pernal Sales 8 18171.25 612.45
#30 Marenghi Mgr   5 17506.75 
#40 OBrien Sales 6 18006.00 846.55
#50 Hanes Mgr   10 20659.80 
#60 Quigley Sales  16808.30 650.25
#70 Rothman Sales 7 16502.83 1152.00
#80 James Clerk  13504.60 128.20
#90 Koonitz Sales 6 18001.75 1386.70
#100 Plotz Mgr   7 18352.80 
#110 Ngan Clerk 5 12508.20 206.60
#120 Naughton Clerk  12954.75 180.00
#130 Yamaguchi Clerk 6 10505.90 75.60
#140 Fraye Mgr   6 21150.00 
#150 Williams Sales 6 19456.50 637.65
#160 Molinare Mgr   7 22959.20 
#170 Kermisch Clerk 4 12258.50 110.10
#180 Abrahams Clerk 3 12009.75 236.50
#190 Sneider Clerk 8 14252.75 126.50
#200 Scoutten Clerk  11508.60 84.20
#210 Lu Mgr   10 20010.00 
#220 Smith Sales 7 17654.50 992.80
#230 Lundquist Clerk 3 13369.80 189.65
#240 Daniels Mgr   5 19260.25 
#250 Wheeler Clerk 6 14460.00 513.30
#260 Jones Mgr   12 21234.00 
#270 Lea Mgr   9 18555.50 
#280 Wilson Sales 9 18674.50 811.50
#290 Quill Mgr   10 19818.00 
#300 Davis Sales 5 15454.50 806.10
#310 Graham Sales 13 21000.00 200.30
#320 Gonzales Sales 4 16858.20 844.00
#330 Burke Clerk 1 10988.00 55.50
#340 Edwards Sales 7 17844.00 1285.00
#350 Gafney Clerk 5 13030.50 188.00
#A00 SPIFFY COMPUTER SERVICE DIV. 000010 A00 None
#B01 PLANNING 000020 A00 None
#C01 INFORMATION CENTER 000030 A00 None
#D01 DEVELOPMENT CENTER  A00 None
#D11 MANUFACTURING SYSTEMS 000060 D01 None
#D21 ADMINISTRATION SYSTEMS 000070 D01 None
#E01 SUPPORT SERVICES 000050 A00 None
#E11 OPERATIONS 000090 E01 None
#E21 SOFTWARE SUPPORT 000100 E01 None
#__ZOS_EXPECTED__
#10 Sanders Mgr   7 18357.50 
#20 Pernal Sales 8 18171.25 612.45
#30 Marenghi Mgr   5 17506.75 
#40 OBrien Sales 6 18006.00 846.55
#50 Hanes Mgr   10 20659.80 
#60 Quigley Sales  16808.30 650.25
#70 Rothman Sales 7 16502.83 1152.00
#80 James Clerk  13504.60 128.20
#90 Koonitz Sales 6 18001.75 1386.70
#100 Plotz Mgr   7 18352.80 
#110 Ngan Clerk 5 12508.20 206.60
#120 Naughton Clerk  12954.75 180.00
#130 Yamaguchi Clerk 6 10505.90 75.60
#140 Fraye Mgr   6 21150.00 
#150 Williams Sales 6 19456.50 637.65
#160 Molinare Mgr   7 22959.20 
#170 Kermisch Clerk 4 12258.50 110.10
#180 Abrahams Clerk 3 12009.75 236.50
#190 Sneider Clerk 8 14252.75 126.50
#200 Scoutten Clerk  11508.60 84.20
#210 Lu Mgr   10 20010.00 
#220 Smith Sales 7 17654.50 992.80
#230 Lundquist Clerk 3 13369.80 189.65
#240 Daniels Mgr   5 19260.25 
#250 Wheeler Clerk 6 14460.00 513.30
#260 Jones Mgr   12 21234.00 
#270 Lea Mgr   9 18555.50 
#280 Wilson Sales 9 18674.50 811.50
#290 Quill Mgr   10 19818.00 
#300 Davis Sales 5 15454.50 806.10
#310 Graham Sales 13 21000.00 200.30
#320 Gonzales Sales 4 16858.20 844.00
#330 Burke Clerk 1 10988.00 55.50
#340 Edwards Sales 7 17844.00 1285.00
#350 Gafney Clerk 5 13030.50 188.00
#A00 SPIFFY COMPUTER SERVICE DIV. 000010 A00 None
#B01 PLANNING 000020 A00 None
#C01 INFORMATION CENTER 000030 A00 None
#D01 DEVELOPMENT CENTER  A00 None
#D11 MANUFACTURING SYSTEMS 000060 D01 None
#D21 ADMINISTRATION SYSTEMS 000070 D01 None
#E01 SUPPORT SERVICES 000050 A00 None
#E11 OPERATIONS 000090 E01 None
#E21 SOFTWARE SUPPORT 000100 E01 None
#__SYSTEMI_EXPECTED__
#10 Sanders Mgr   7 18357.50 
#20 Pernal Sales 8 18171.25 612.45
#30 Marenghi Mgr   5 17506.75 
#40 OBrien Sales 6 18006.00 846.55
#50 Hanes Mgr   10 20659.80 
#60 Quigley Sales  16808.30 650.25
#70 Rothman Sales 7 16502.83 1152.00
#80 James Clerk  13504.60 128.20
#90 Koonitz Sales 6 18001.75 1386.70
#100 Plotz Mgr   7 18352.80 
#110 Ngan Clerk 5 12508.20 206.60
#120 Naughton Clerk  12954.75 180.00
#130 Yamaguchi Clerk 6 10505.90 75.60
#140 Fraye Mgr   6 21150.00 
#150 Williams Sales 6 19456.50 637.65
#160 Molinare Mgr   7 22959.20 
#170 Kermisch Clerk 4 12258.50 110.10
#180 Abrahams Clerk 3 12009.75 236.50
#190 Sneider Clerk 8 14252.75 126.50
#200 Scoutten Clerk  11508.60 84.20
#210 Lu Mgr   10 20010.00 
#220 Smith Sales 7 17654.50 992.80
#230 Lundquist Clerk 3 13369.80 189.65
#240 Daniels Mgr   5 19260.25 
#250 Wheeler Clerk 6 14460.00 513.30
#260 Jones Mgr   12 21234.00 
#270 Lea Mgr   9 18555.50 
#280 Wilson Sales 9 18674.50 811.50
#290 Quill Mgr   10 19818.00 
#300 Davis Sales 5 15454.50 806.10
#310 Graham Sales 13 21000.00 200.30
#320 Gonzales Sales 4 16858.20 844.00
#330 Burke Clerk 1 10988.00 55.50
#340 Edwards Sales 7 17844.00 1285.00
#350 Gafney Clerk 5 13030.50 188.00
#A00 SPIFFY COMPUTER SERVICE DIV. 000010 A00 None
#B01 PLANNING 000020 A00 None
#C01 INFORMATION CENTER 000030 A00 None
#D01 DEVELOPMENT CENTER  A00 None
#D11 MANUFACTURING SYSTEMS 000060 D01 None
#D21 ADMINISTRATION SYSTEMS 000070 D01 None
#E01 SUPPORT SERVICES 000050 A00 None
#E11 OPERATIONS 000090 E01 None
#E21 SOFTWARE SUPPORT 000100 E01 None
#__IDS_EXPECTED__
#10 Sanders Mgr   7 18357.50 
#20 Pernal Sales 8 18171.25 612.45
#30 Marenghi Mgr   5 17506.75 
#40 OBrien Sales 6 18006.00 846.55
#50 Hanes Mgr   10 20659.80 
#60 Quigley Sales  16808.30 650.25
#70 Rothman Sales 7 16502.83 1152.00
#80 James Clerk  13504.60 128.20
#90 Koonitz Sales 6 18001.75 1386.70
#100 Plotz Mgr   7 18352.80 
#110 Ngan Clerk 5 12508.20 206.60
#120 Naughton Clerk  12954.75 180.00
#130 Yamaguchi Clerk 6 10505.90 75.60
#140 Fraye Mgr   6 21150.00 
#150 Williams Sales 6 19456.50 637.65
#160 Molinare Mgr   7 22959.20 
#170 Kermisch Clerk 4 12258.50 110.10
#180 Abrahams Clerk 3 12009.75 236.50
#190 Sneider Clerk 8 14252.75 126.50
#200 Scoutten Clerk  11508.60 84.20
#210 Lu Mgr   10 20010.00 
#220 Smith Sales 7 17654.50 992.80
#230 Lundquist Clerk 3 13369.80 189.65
#240 Daniels Mgr   5 19260.25 
#250 Wheeler Clerk 6 14460.00 513.30
#260 Jones Mgr   12 21234.00 
#270 Lea Mgr   9 18555.50 
#280 Wilson Sales 9 18674.50 811.50
#290 Quill Mgr   10 19818.00 
#300 Davis Sales 5 15454.50 806.10
#310 Graham Sales 13 21000.00 200.30
#320 Gonzales Sales 4 16858.20 844.00
#330 Burke Clerk 1 10988.00 55.50
#340 Edwards Sales 7 17844.00 1285.00
#350 Gafney Clerk 5 13030.50 188.00
#A00 SPIFFY COMPUTER SERVICE DIV. 000010 A00 None
#B01 PLANNING 000020 A00 None
#C01 INFORMATION CENTER 000030 A00 None
#D01 DEVELOPMENT CENTER  A00 None
#D11 MANUFACTURING SYSTEMS 000060 D01 None
#D21 ADMINISTRATION SYSTEMS 000070 D01 None
#E01 SUPPORT SERVICES 000050 A00 None
#E11 OPERATIONS 000090 E01 None
#E21 SOFTWARE SUPPORT 000100 E01 None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2025
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import ibm_db_dbi
import config
from testfunctions import IbmDbTestFunctions


class IbmDbTestCase(unittest.TestCase):

    def test_317_connErrormsg_connError_DBI(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_317)

    def run_test_317(self):
        try:
            # Intentionally wrong credentials to trigger connection failure
            conn = ibm_db_dbi.connect(config.database, "wrongUser", "wrongPassword")
            print(conn)  # Should not get here
        except Exception:
            print(ibm_db_dbi.conn_errormsg())
            print(ibm_db_dbi.conn_error())

#__END__
#__LUW_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001  SQLCODE=-30082
#08001
#__ZOS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001  SQLCODE=-30082
#08001
#__SYSTEMI_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001  SQLCODE=-30082
#08001
#__IDS_EXPECTED__
#[IBM][CLI Driver] SQL30082N  Security processing failed with reason "24" ("USERNAME AND/OR PASSWORD INVALID").  SQLSTATE=08001  SQLCODE=-30082
#08001



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2013
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_6792_FieldTypeRetStrDatetimeTimestamp(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_6792)

    def run_test_6792(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        if conn:
            drop = 'DROP TABLE table_6792'
            result = ''
            try:
                result = ibm_db.exec_immediate(conn, drop)
            except:
                pass

            t_val = '10:42:34'
            d_val = '1981-07-08'
            ts_val = '1981-07-08 10:42:34'
            ts_withT_val = '2013-06-06T15:30:39'

            server = ibm_db.server_info( conn )
            if (server.DBMS_NAME[0:3] == 'IDS'):
                statement = "CREATE TABLE table_6792 (col1 DATETIME HOUR TO SECOND, col2 DATE, col3 DATETIME YEAR TO SECOND, col4 DATETIME YEAR TO SECOND)"
                result = ibm_db.exec_immediate(conn, statement)
                statement = "INSERT INTO table_6792 (col1, col2, col3) values (?, ?, ?)"
                stmt = ibm_db.prepare(conn, statement)
                result = ibm_db.execute(stmt, (t_val, d_val, ts_val))
            else:
                statement = "CREATE TABLE table_6792 (col1 TIME, col2 DATE, col3 TIMESTAMP, col4 TIMESTAMP)"
                result = ibm_db.exec_immediate(conn, statement)
                statement = "INSERT INTO table_6792 (col1, col2, col3, col4) values (?, ?, ?, ?)"
                stmt = ibm_db.prepare(conn, statement)
                result = ibm_db.execute(stmt, (t_val, d_val, ts_val, ts_withT_val))

            statement = "SELECT * FROM table_6792"
            result = ibm_db.exec_immediate(conn, statement)

            for i in range(0, ibm_db.num_fields(result)):
                print(str(i) + ":" + ibm_db.field_type(result,i))

            statement = "SELECT * FROM table_6792"
            stmt = ibm_db.prepare(conn, statement)
            rc = ibm_db.execute(stmt)
            result = ibm_db.fetch_row(stmt)
            while ( result ):
                row0 = ibm_db.result(stmt, 0)
                row1 = ibm_db.result(stmt, 1)
                row2 = ibm_db.result(stmt, 2)
                row3 = ibm_db.result(stmt, 3)
                print(row0)
                print(row1)
                print(row2)
                print(row3)
                result = ibm_db.fetch_row(stmt)

            ibm_db.close(conn)
        else:
            print("Connection failed.")

#__END__
#__LUW_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__ZOS_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__SYSTEMI_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39
#__IDS_EXPECTED__
#0:time
#1:date
#2:timestamp
#3:timestamp
#10:42:34
#1981-07-08
#1981-07-08 10:42:34
#2013-06-06 15:30:39



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_034_FetchAssoc(self):
        obj = IbmDbTestFunctions()
        obj.assert_expect(self.run_test_034)

    def run_test_034(self):
        conn = ibm_db.connect(config.database, config.user, config.password)

        server = ibm_db.server_info( conn )
        if (server.DBMS_NAME[0:3] == 'IDS'):
            op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
            ibm_db.set_option(conn, op, 1)

        result = ibm_db.exec_immediate(conn, "select * from staff")
        row = ibm_db.fetch_assoc(result)
        if( row ):
            #printf("%5d  ",row['ID'])
            #printf("%-10s ",row['NAME'])
            #printf("%5d ",row['DEPT'])
            #printf("%-7s ",row['JOB'])
            #printf("%5d ", row['YEARS'])
            #printf("%15s ", row['SALARY'])
            #printf("%10s ", row['COMM'])
            #puts ""
            print("%5d %-10s %5d %-7s %5d %15s %10s" % (row['ID'], row['NAME'], row['DEPT'], row['JOB'], row['YEARS'], row['SALARY'], row['COMM']))

        ibm_db.close(conn)

#__END__
#__LUW_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__ZOS_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__SYSTEMI_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None
#__IDS_EXPECTED__
#   10 Sanders       20 Mgr         7        18357.50       None



#
#  Licensed Materials - Property of IBM
#
#  (c) Copyright IBM Corp. 2007-2008
#

from __future__ import print_function
import sys
import unittest
import ibm_db
import config
from testfunctions import IbmDbTestFunctions

class IbmDbTestCase(unittest.TestCase):

    def test_061_Tables_02(self):
        obj = IbmDbTestFunctions()
        obj.assert_expectf(self.run_test_061)

    def run_test_061(self):
        conn = ibm_db.connect(config.database, config.user, config.password)
        server = ibm_db.server_info( conn )

        create = 'CREATE SCHEMA AUTHORIZATION t'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t1( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t2( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t3( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        create = 'CREATE TABLE t.t4( c1 integer, c2 varchar(40))'
        try:
            result = ibm_db.exec_immediate(conn, create)
        except:
            pass

        if conn:
            server = ibm_db.server_info( conn )
            if (server.DBMS_NAME[0:3] == 'IDS'):
                op = {ibm_db.ATTR_CASE: ibm_db.CASE_UPPER}
                ibm_db.set_option(conn, op, 1)

            if (server.DBMS_NAME[0:3] == 'IDS'):
                result = ibm_db.tables(conn, None, 't');
            else:
                result = ibm_db.tables(conn, None, 'T');
            i = 0
            row = ibm_db.fetch_both(result)
            while ( row ):
                str = row['TABLE_SCHEM'] + row['TABLE_NAME'] + row['TABLE_TYPE']
                if (i < 4):
                    print(str)
                i = i + 1
                row = ibm_db.fetch_both(result)

            ibm_db.exec_immediate(conn, 'DROP TABLE t.t1')
            ibm_db.exec_immediate(conn, 'DROP TABLE t.t2')
            ibm_db.exec_immediate(conn, 'DROP TABLE t.t3')
            ibm_db.exec_immediate(conn, 'DROP TABLE t.t4')

            print("done!")
        else:
            print("no connection: %s" % ibm_db.conn_errormsg())

#__END__
#__LUW_EXPECTED__
#TT1TABLE
#TT2TABLE
#TT3TABLE
#TT4TABLE
#done!
#__ZOS_EXPECTED__
#TT1TABLE
#TT2TABLE
#TT3TABLE
#TT4TABLE
#done!
#__SYSTEMI_EXPECTED__
#TT1TABLE
#TT2TABLE
#TT3TABLE
#TT4TABLE
#done!
#__IDS_EXPECTED__
#tt1TABLE%s
#tt2TABLE%s
#tt3TABLE%s
#tt4TABLE%s
#done!
